(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "@babel/runtime/helpers/extends", "core-js/modules/web.dom-collections.iterator.js", "react", "react-native", "../Box", "./WebViewThemed", "./YoutubeIframeThemed", "./size", "./props"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("@babel/runtime/helpers/extends"), require("core-js/modules/web.dom-collections.iterator.js"), require("react"), require("react-native"), require("../Box"), require("./WebViewThemed"), require("./YoutubeIframeThemed"), require("./size"), require("./props"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global._extends, global.webDomCollectionsIterator, global.react, global.reactNative, global.Box, global.WebViewThemed, global.YoutubeIframeThemed, global.size, global.props);
    global.EmbedNative = mod.exports;
  }
})(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : this, function (_exports, _extends2, _webDomCollectionsIterator, _react, _reactNative, _Box, _WebViewThemed, _YoutubeIframeThemed, _size, _props) {
  "use strict";

  var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.default = void 0;
  _extends2 = _interopRequireDefault(_extends2);
  _react = _interopRequireWildcard(_react);
  _Box = _interopRequireDefault(_Box);
  _WebViewThemed = _interopRequireDefault(_WebViewThemed);
  _YoutubeIframeThemed = _interopRequireDefault(_YoutubeIframeThemed);

  function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

  function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

  /**
   * File: /src/components/Embed/Embed.native.tsx
   * Project: @native-theme-ui/core
   * File Created: 18-07-2022 06:25:17
   * Author: Clay Risser
   * -----
   * Last Modified: 20-07-2022 00:55:37
   * Modified By: Manikanta
   * -----
   * Risser Labs LLC (c) Copyright 2021 - 2022
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   *     http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  const Embed = props => {
    const viewRef = (0, _react.useRef)(null);
    const [renderedSize, setRenderedSize] = (0, _react.useState)([null, null]);
    const sx = { ...(props.height ? {
        height: props.height
      } : {}),
      ...(props.width ? {
        width: props.width
      } : {}),
      border: props.frameBorder,
      ...Embed.defaultSx,
      ...props.sx
    };
    sx.width = (0, _size.useCalculateSize)(sx.width, sx.height, props.ratio, _size.SizeDimension.Width) || renderedSize[0];
    sx.height = (0, _size.useCalculateSize)(sx.height, sx.width, props.ratio, _size.SizeDimension.Height);
    const {
      baseProps,
      iframeProps
    } = (0, _props.splitProps)(props, sx);
    (0, _react.useEffect)(() => {
      if (!viewRef.current) return;
      viewRef.current.measure((_x, _y, width, height) => {
        setRenderedSize([width, height]);
      });
    }, []);
    const youtubeVideoId = typeof props.src === "string" && (props.src.indexOf("youtube.com/") > -1 || props.src.indexOf("youtube/") > -1) && Array.from(props.src.match(/[^/]+$/g) || []).join("").trim() || null;

    function renderWebView() {
      if (!props.src) return [];

      if (youtubeVideoId) {
        const youtubeIframeThemedProps = { ...props
        };
        delete youtubeIframeThemedProps.src;
        return /*#__PURE__*/_react.default.createElement(_YoutubeIframeThemed.default, {
          initialPlayerParams: { ...(typeof iframeProps.allowFullScreen === "boolean" ? {
              preventFullScreen: !iframeProps.allowFullScreen
            } : {})
          },
          defaultHeight: 400,
          videoId: youtubeVideoId,
          useLocalHTML: true,
          sx: {
            width: sx.width,
            height: sx.height
          }
        });
      }

      return /*#__PURE__*/_react.default.createElement(_Box.default, {
        sx: {
          height: sx.height,
          width: sx.width || (!sx.height ? "50%" : sx.width)
        }
      }, /*#__PURE__*/_react.default.createElement(_WebViewThemed.default, {
        source: {
          uri: props.src
        },
        originWhitelist: ["*"],
        sx: {
          width: sx.width,
          height: sx.height
        }
      }));
    }

    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      ref: viewRef
    }, /*#__PURE__*/_react.default.createElement(_Box.default, (0, _extends2.default)({}, baseProps, {
      sx: { ...sx,
        height: sx.height,
        width: sx.width || (!sx.height ? "100%" : sx.width)
      }
    }), renderWebView()));
  };

  Embed.defaultProps = {
    ratio: 16 / 9
  };
  Embed.defaultSx = {};
  var _default = Embed;
  _exports.default = _default;
});
//# sourceMappingURL=Embed.native.js.map